# valkyrie_util

![Upload Python Package](https://github.com/davidjcastner/valkyrie_util/workflows/Upload%20Python%20Package/badge.svg?event=release)
![Lint & Test Python Package](https://github.com/davidjcastner/valkyrie_util/workflows/Lint%20&%20Test%20Python%20Package/badge.svg)

A python library of various math and performance tools
